@@ -532,7 +532,7 @@ local robots =
       }
     },
     subgroup="capsule",
-    order="e-a-a",
+    order = "d[defender]-a[robot]",
     max_health = 60,
     alert_when_damaged = false,
     collision_box = {{0, 0}, {0, 0}},
@@ -548,7 +548,6 @@ local robots =
     working_sound =
     {
       sound = { filename = "__base__/sound/fight/defender-robot-loop.ogg", volume = 0.7 },
-      apparent_volume = 1,
       persistent = true
     },
     destroy_action =
@@ -729,7 +728,7 @@ local robots =
       }
     },
     subgroup = "capsule",
-    order = "e-a-b",
+    order = "e[distractor]-a[robot]",
     factoriopedia_simulation = simulations.factoriopedia_distractor,
     max_health = 180,
     alert_when_damaged = false,
@@ -808,7 +807,7 @@ local robots =
       }
     },
     subgroup="capsule",
-    order="e-a-c",
+    order = "f[destroyer]-a[robot]",
     max_health = 60,
     alert_when_damaged = false,
     collision_box = {{0, 0}, {0, 0}},
