@@ -14,16 +14,6 @@ return
   }
 end
 
-sounds.plant = sound_variations("__base__/sound/walking/plant/plant", 5, 0.4)
-sounds.big_bush = sound_variations("__base__/sound/walking/plant/bush-big", 7, 0.3)
-sounds.small_bush = sound_variations("__base__/sound/walking/plant/bush-small", 7, 0.6)
-sounds.pebble = sound_variations("__base__/sound/walking/pebble/stones", 9, 0.6)
-sounds.hairy_grass = sound_variations("__base__/sound/walking/decorative-grass", 10, 0.3)
-sounds.carpet_grass = sound_variations("__base__/sound/walking/decorative-grass", 10, 0.2)
-sounds.mud = sound_variations("__base__/sound/walking/decorative-mud", 10, 0.3)
-sounds.ore = sound_variations("__base__/sound/walking/resources/ore", 10, 0.7)
-sounds.oil = sound_variations("__base__/sound/walking/resources/oil", 7, 0.7)
-sounds.rails = sound_variations("__base__/sound/walking/rails/rails", 12, 0.6)
 sounds.tree_leaves = sound_variations("__base__/sound/particles/tree-leaves", 5, 0.35)
 sounds.mine_fish = sound_variations("__core__/sound/mine-fish", 5, 0.8)
 sounds.eat_fish = sound_variations("__base__/sound/eat", 5, 0.6)
@@ -103,22 +93,31 @@ end
 sounds.inserter_basic =
 {
   match_progress_to_activity = true,
-  sound = sound_variations("__base__/sound/inserter-basic", 5, 0.5, { volume_multiplier("main-menu", 2), volume_multiplier("tips-and-tricks", 1.8) } ),
-  audible_distance_modifier = 0.3
+  sound =
+  {
+    variations = sound_variations("__base__/sound/inserter-basic", 5, 0.5, {volume_multiplier("main-menu", 2), volume_multiplier("tips-and-tricks", 1.8)}),
+    audible_distance_modifier = 0.3
+  }
 }
 
 sounds.inserter_fast =
 {
   match_progress_to_activity = true,
-  sound = sound_variations("__base__/sound/inserter-fast", 5, 0.5, { volume_multiplier("main-menu", 1.6), volume_multiplier("tips-and-tricks", 2) } ),
-  audible_distance_modifier = 0.3
+  sound =
+  {
+    variations = sound_variations("__base__/sound/inserter-fast", 5, 0.5, {volume_multiplier("main-menu", 1.6), volume_multiplier("tips-and-tricks", 2)}),
+    audible_distance_modifier = 0.3
+  }
 }
 
 sounds.inserter_long_handed =
 {
   match_progress_to_activity = true,
-  sound = sound_variations("__base__/sound/inserter-long-handed", 5, 0.3, volume_multiplier("tips-and-tricks", 1.8)),
-  audible_distance_modifier = 0.5
+  sound =
+  {
+    variations = sound_variations("__base__/sound/inserter-long-handed", 5, 0.3, volume_multiplier("tips-and-tricks", 1.8)),
+    audible_distance_modifier = 0.5
+  }
 }
 
 sounds.tree_mined = sound_variations("__base__/sound/particles/tree-mined", 5, 0.4)
@@ -193,57 +192,77 @@ sounds.tree_ambient_leaves =
 
 sounds.splitter =
 {
-  sound = sound_variations("__base__/sound/splitters/splitter", 6, 0.2, volume_multiplier("tips-and-tricks", 1.44)),
-  max_sounds_per_type = 3,
-  audible_distance_modifier = 0.45
+  sound =
+  {
+    variations = sound_variations("__base__/sound/splitters/splitter", 6, 0.2, volume_multiplier("tips-and-tricks", 1.44)),
+    audible_distance_modifier = 0.45
+  },
+  max_sounds_per_prototype = 3,
 }
 
 sounds.fast_splitter =
 {
-  sound = sound_variations("__base__/sound/splitters/fast-splitter", 5, 0.2),
-  max_sounds_per_type = 3,
-  audible_distance_modifier = 0.45
+  sound = {variations = sound_variations("__base__/sound/splitters/fast-splitter", 5, 0.2), audible_distance_modifier = 0.45},
+  max_sounds_per_prototype = 3,
 }
 
 sounds.express_splitter =
 {
-  sound = sound_variations("__base__/sound/splitters/express-splitter", 5, 0.2),
-  max_sounds_per_type = 3,
-  audible_distance_modifier = 0.45
+  sound = {variations = sound_variations("__base__/sound/splitters/express-splitter", 5, 0.2), audible_distance_modifier = 0.45},
+  max_sounds_per_prototype = 3,
 }
 
 sounds.loader =
 {
-  sound = { filename = "__base__/sound/transport-belt.ogg", volume = 0.3 },
-  max_sounds_per_type = 3,
-  audible_distance_modifier = 0.45
+  sound = {filename = "__base__/sound/transport-belt.ogg", volume = 0.3, audible_distance_modifier = 0.45},
+  max_sounds_per_prototype = 3,
 }
 
 sounds.fast_loader =
 {
-  sound = { filename = "__base__/sound/fast-transport-belt.ogg", volume = 0.3 },
-  max_sounds_per_type = 3,
-  audible_distance_modifier = 0.45
+  sound = {filename = "__base__/sound/fast-transport-belt.ogg", volume = 0.3, audible_distance_modifier = 0.45},
+  max_sounds_per_prototype = 3,
 }
 
 sounds.express_loader =
 {
-  sound = { filename = "__base__/sound/express-transport-belt.ogg", volume = 0.3 },
-  max_sounds_per_type = 3,
-  audible_distance_modifier = 0.45
+  sound = {filename = "__base__/sound/express-transport-belt.ogg", volume = 0.3, audible_distance_modifier = 0.45},
+  max_sounds_per_prototype = 3,
+}
+
+sounds.spidertron_leg =
+{
+  variations = sound_variations("__base__/sound/spidertron/spidertron-leg", 5, 0.1, volume_multiplier("main-menu", 7.5)),
+  audible_distance_modifier = 0.5
 }
 
-sounds.spidertron_leg = sound_variations("__base__/sound/spidertron/spidertron-leg", 5, 0.1, volume_multiplier("main-menu", 7.5))
 sounds.pipe =
 {
-  sound = { filename = "__base__/sound/pipe.ogg", volume = 0.45 },
+  sound = {filename = "__base__/sound/pipe.ogg", volume = 0.7, audible_distance_modifier = 0.5,},
   persistent = true,
   fade_in_ticks = 10,
   fade_out_ticks = 20,
   volume_smoothing_window_size = 20,
+  match_volume_to_activity = true,
+  activity_to_volume_modifiers =
+  {
+    multiplier = 1.0,
+    minimum = 0.5,
+    maximum = 1.0,
+    offset = 0,
+  },
+  match_speed_to_activity = true,
+  activity_to_speed_modifiers =
+  {
+    multiplier = 0.4,
+    minimum = 1.0,
+    maximum = 1.2,
+    offset = -2.3,
+  },
 }
 sounds.train_brakes =
 {
+  category = "environment",
   filename = "__base__/sound/train-breaks.ogg",
   volume = 0.3,
   aggregation = {max_count = 1, remove = true},
@@ -251,6 +270,7 @@ sounds.train_brakes =
 }
 sounds.train_brake_screech =
 {
+  category = "environment",
   variations = sound_variations("__base__/sound/train-brake-screech", 2, 0.3, volume_multiplier("driving", 1.15)),
   aggregation = {max_count = 1, remove = true},
 }
@@ -279,39 +299,53 @@ sounds.train_wagon_wheels =
   },
   fade_in_ticks = 10,
   fade_out_ticks = 20,
-  max_sounds_per_type = 2,
+  max_sounds_per_prototype = 2,
 }
 
 --Entities open close
 
 sounds.ammo_open = { filename = "__base__/sound/open-close/ammo-large-open.ogg", volume = 0.57 }
 sounds.ammo_close = { filename = "__base__/sound/open-close/ammo-large-close.ogg", volume = 0.6 }
+sounds.armor_open = { filename = "__base__/sound/armor-open.ogg", volume = 0.8 }
+sounds.armor_close = { filename = "__base__/sound/armor-close.ogg", volume = 0.8 }
 sounds.artillery_open = { filename = "__base__/sound/artillery-open.ogg", volume = 0.57 }
 sounds.artillery_close = { filename = "__base__/sound/artillery-close.ogg", volume = 0.6 }
-sounds.cargo_wagon_open = { filename = "__base__/sound/cargo-wagon-open.ogg", volume = 0.55 }
-sounds.cargo_wagon_close = { filename = "__base__/sound/cargo-wagon-close.ogg", volume = 0.54 }
+sounds.cargo_wagon_open = { filename = "__base__/sound/cargo-wagon-open.ogg", volume = 0.27 }
+sounds.cargo_wagon_close = { filename = "__base__/sound/cargo-wagon-close.ogg", volume = 0.27 }
 sounds.combinator_open = { filename = "__base__/sound/open-close/combinator-open.ogg", volume = 0.55 }
 sounds.combinator_close = { filename = "__base__/sound/open-close/combinator-close.ogg", volume = 0.54 }
-sounds.drill_open = { filename = "__base__/sound/open-close/drill-open.ogg", volume = 0.6 }
-sounds.drill_close = { filename = "__base__/sound/open-close/drill-close.ogg", volume = 0.6 }
+sounds.drill_open = { filename = "__base__/sound/open-close/drill-open.ogg", volume = 0.9 }
+sounds.drill_close = { filename = "__base__/sound/open-close/drill-close.ogg", volume = 0.9 }
 sounds.electric_network_open = { filename = "__base__/sound/electric-network-open.ogg", volume = 0.6 }
 sounds.electric_network_close = { filename = "__base__/sound/electric-network-close.ogg", volume = 0.6 }
 sounds.electric_large_open = { filename = "__base__/sound/open-close/electric-large-open.ogg", volume = 0.6 }
 sounds.electric_large_close = { filename = "__base__/sound/open-close/electric-large-close.ogg", volume = 0.6 }
 sounds.inserter_open = { filename = "__base__/sound/open-close/inserter-open.ogg", volume = 0.6 }
 sounds.inserter_close = { filename = "__base__/sound/open-close/inserter-close.ogg", volume = 0.5 }
+sounds.lab_open = { filename = "__base__/sound/open-close/lab-open.ogg", volume = 0.8 }
+sounds.lab_close = { filename = "__base__/sound/open-close/lab-close.ogg", volume = 0.8 }
 sounds.machine_open = { filename = "__base__/sound/machine-open.ogg", volume = 0.5 }
-sounds.machine_close = { filename = "__base__/sound/machine-close.ogg", volume = 0.5 }
+sounds.machine_close = { filename = "__base__/sound/machine-close.ogg", volume = 0.29 }
+sounds.mech_small_open = {filename =  "__base__/sound/open-close/mechanical-inventory-move.ogg", volume = 1.0}
+sounds.mech_small_close = {filename = "__base__/sound/open-close/mechanical-inventory-pickup.ogg", volume = 1.0}
+sounds.mech_large_open = {filename =  "__base__/sound/open-close/mechanical-large-open.ogg", volume = 0.5}
+sounds.mech_large_close = {filename = "__base__/sound/open-close/mechanical-large-close.ogg", volume = 0.5}
+sounds.metallic_chest_open = { filename = "__base__/sound/metallic-chest-open.ogg", volume = 0.43 }
+sounds.metallic_chest_close = { filename = "__base__/sound/metallic-chest-close.ogg", volume = 0.3 }
 sounds.metal_small_open = { filename = "__base__/sound/open-close/metal-small-open.ogg", volume = 0.8 }
 sounds.metal_small_close = { filename = "__base__/sound/open-close/metal-small-close.ogg", volume = 0.8 }
 sounds.metal_large_open = { filename = "__base__/sound/open-close/metal-large-open.ogg", volume = 0.8 }
 sounds.metal_large_close = { filename = "__base__/sound/open-close/metal-large-close.ogg", volume = 0.7 }
 sounds.rail_signal_open = { filename = "__base__/sound/open-close/rail-signal-open.ogg", volume = 0.6 }
 sounds.rail_signal_close = { filename = "__base__/sound/open-close/rail-signal-close.ogg", volume = 0.6 }
-sounds.steam_open = { filename = "__base__/sound/open-close/steam-open.ogg", volume = 0.57 }
-sounds.steam_close = { filename = "__base__/sound/open-close/steam-close.ogg", volume = 0.5 }
+sounds.steam_open = { filename = "__base__/sound/open-close/steam-open.ogg", volume = 0.4 }
+sounds.steam_close = { filename = "__base__/sound/open-close/steam-close.ogg", volume = 0.4 }
 sounds.transport_belt_open = { filename = "__base__/sound/open-close/transport-belt-open.ogg", volume = 0.7 }
 sounds.transport_belt_close = { filename = "__base__/sound/open-close/transport-belt-close.ogg", volume = 0.6 }
+sounds.turret_open = { filename = "__base__/sound/open-close/turret-open.ogg", volume = 0.8 }
+sounds.turret_close = { filename = "__base__/sound/open-close/turret-close.ogg", volume = 0.8 }
+sounds.reactor_open = { filename = "__base__/sound/open-close/reactor-open.ogg", volume = 1.0 }
+sounds.reactor_close = { filename = "__base__/sound/open-close/reactor-close.ogg", volume = 1.0 }
 
 sounds.roboport_door_open =
 {
@@ -319,6 +353,7 @@ sounds.roboport_door_open =
     type = "play-sound",
     sound =
     {
+      category = "environment",
       filename = "__base__/sound/roboport-door.ogg",
       volume = 0.3,
       min_speed = 1,
@@ -334,6 +369,7 @@ sounds.roboport_door_close =
     type = "play-sound",
     sound =
     {
+      category = "environment",
       filename = "__base__/sound/roboport-door-close.ogg",
       volume = 0.2,
       min_speed = 1,
@@ -363,7 +399,7 @@ sounds.flying_robot = function(volume)
       { filename = "__base__/sound/flying-robot-4.ogg", volume = 0.43, modifiers = volume_multiplier("main-menu", 1.3) },
       { filename = "__base__/sound/flying-robot-5.ogg", volume = 0.43, modifiers = volume_multiplier("main-menu", 1.3) },
     },
-    max_sounds_per_type = 20,
+    max_sounds_per_prototype = 20,
     fade_in_ticks = 8,
     fade_out_ticks = 10,
     probability = 1 / (10 * 60) -- average pause between the sound is 10 seconds
@@ -390,7 +426,7 @@ sounds.construction_robot = function(volume)
       { filename = "__base__/sound/flying-robot-4.ogg", volume = 0.43, modifiers = volume_multiplier("main-menu", 1.3) },
       { filename = "__base__/sound/flying-robot-5.ogg", volume = 0.43, modifiers = volume_multiplier("main-menu", 1.3) },
     },
-    max_sounds_per_type = 20,
+    max_sounds_per_prototype = 20,
     fade_in_ticks = 8,
     fade_out_ticks = 8,
     probability = 1 / (10 * 60) -- average pause between the sound is 10 seconds
@@ -524,7 +560,17 @@ sounds.throw_grenade =
   variations = sound_variations("__base__/sound/fight/throw-grenade", 5, 0.4),
   priority = 64
 }
-
+sounds.spidertron_rocket_launcher =
+{
+  variations = make_sound_variations({
+    number_of_variations = 3,
+    filename = "__base__/sound/spidertron/spidertron-rocket-launcher",
+    volume = 0.7,
+    modifiers = volume_multiplier("main-menu", 0.7),
+    min_speed = 1.0,
+    max_speed = 1.1,
+  }),
+}
 sounds.poison_capsule_explosion =
 {
   category = "weapon",
@@ -665,7 +711,8 @@ sounds.nuclear_explosion = function(volume)
       duration = 800,
       play_for = "everything"
     },
-    variations = sound_variations("__base__/sound/fight/nuclear-explosion", 3, volume)
+    variations = sound_variations("__base__/sound/fight/nuclear-explosion", 3, volume),
+    audible_distance_modifier = 3,
   }
 end
 
@@ -678,7 +725,9 @@ sounds.nuclear_explosion_aftershock = function(volume)
       max_count = 1,
       remove = true
     },
-    variations = {{ filename = "__base__/sound/fight/nuclear-explosion-aftershock.ogg", volume = volume }}
+    filename = "__base__/sound/fight/nuclear-explosion-aftershock.ogg",
+    volume = volume,
+    audible_distance_modifier = 3,
   }
 end
 
@@ -1018,7 +1067,7 @@ sounds.biter_calls = function(min_volume, max_volume)
       variations = sound_variations_with_volume_variations("__base__/sound/creatures/biter-call", 5, min_volume, max_volume or min_volume)
     },
     probability = 1 / (12 * 60), -- average pause between the sound is 12 seconds
-    max_sounds_per_type = 2
+    max_sounds_per_prototype = 2
   }
 end
 
@@ -1031,7 +1080,7 @@ sounds.biter_calls_big = function(min_volume, max_volume)
       variations = sound_variations_with_volume_variations("__base__/sound/creatures/biter-call-big", 6, min_volume, max_volume or min_volume)
     },
     probability = 1 / (4 * 60), -- average pause between the sound is 4 seconds
-    max_sounds_per_type = 2
+    max_sounds_per_prototype = 2
   }
 end
 
@@ -1044,7 +1093,7 @@ sounds.biter_calls_behemoth = function(min_volume, max_volume)
       variations = sound_variations_with_volume_variations("__base__/sound/creatures/biter-call-behemoth", 6, min_volume, max_volume or min_volume)
     },
     probability = 1 / (4 * 60), -- average pause between the sound is 4 seconds
-    max_sounds_per_type = 2
+    max_sounds_per_prototype = 2
   }
 end
 
@@ -1113,7 +1162,7 @@ sounds.spitter_calls = function(min_volume, max_volume)
       variations = sound_variations_with_volume_variations("__base__/sound/creatures/spitter-call-small", 9, min_volume, max_volume or min_volume, volume_multiplier("main-menu", 0.5))
     },
     probability = 1 / (4 * 60), -- average pause between the sound is 4 seconds
-    max_sounds_per_type = 2
+    max_sounds_per_prototype = 2
   }
 end
 
@@ -1126,7 +1175,7 @@ sounds.spitter_calls_med = function(min_volume, max_volume)
       variations = sound_variations_with_volume_variations("__base__/sound/creatures/spitter-call-med", 10, min_volume, max_volume or min_volume)
     },
     probability = 1 / (8 * 60), -- average pause between the sound is 8 seconds
-    max_sounds_per_type = 2
+    max_sounds_per_prototype = 2
   }
 end
 
@@ -1139,7 +1188,7 @@ sounds.spitter_calls_big = function(min_volume, max_volume)
       variations = sound_variations_with_volume_variations("__base__/sound/creatures/spitter-call-big", 5, min_volume, max_volume or min_volume)
     },
     probability = 1 / (4 * 60), -- average pause between the sound is 4 seconds
-    max_sounds_per_type = 2
+    max_sounds_per_prototype = 2
   }
 end
 
